Package: leapR
Title: Layered enrichment analysis of pathways R
Version: 1.0.0
Authors@R: c(
    person("Sara", "Gosline", email = "sara.gosline@pnnl.gov", role = c('aut',"cre"), comment = c(ORCID = "0000-0002-6534-4774")),
    person("Jason", "McDermott", email = "jason.mcdermott@pnnl.gov", role = "aut"),
    person("Jeremy",'Jacobson', email = 'jeremy.jacobson@pnnl.gov', role = 'aut'),
    person("Vincent","Danna",email="vincent.danna@pnnl.gov",role='ctb'),
    person("National Institutes of Health", , role = 'fnd'))
Description: leapR is a package that identifies pathways that are enriched across diverse 'omics experiments. It leverages any tabular expression data (proteomics, transcriptomics) using the `SummarizedExperiment` object. It works with any pathway in the .gct file format. 
Depends: R (>= 4.5.0)
Encoding: UTF-8
LazyData: false
RoxygenNote: 7.3.3
biocViews: GeneSetEnrichment, Proteomics, Pathways, GeneExpression,
        Transcriptomics
Imports: stats, gplots, readr, tibble, gplots, methods, ggplot2, dplyr,
        stringr, tidyr, SummarizedExperiment, BiocStyle
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
License: MIT + file LICENSE
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/leapR
git_branch: RELEASE_3_23
git_last_commit: 7469969
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:08:49 UTC; biocbuild
Author: Sara Gosline [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6534-4774>),
  Jason McDermott [aut],
  Jeremy Jacobson [aut],
  Vincent Danna [ctb],
  National Institutes of Health [fnd]
Maintainer: Sara Gosline <sara.gosline@pnnl.gov>
